@@ -1,4 +1,4 @@
-# Copyright 2022 rev1si0n (ihaven0emmail@gmail.com). All rights reserved.
+# Copyright 2022 rev1si0n (https://github.com/rev1si0n). All rights reserved.
 #
 # Distributed under MIT license.
 # See file LICENSE for detail or copy at https://opensource.org/licenses/MIT
@@ -8,6 +8,8 @@ class DeadSystemException(Exception):
     """ Exception """
 class DeviceUnavailable(Exception):
     """ Exception """
+class DuplicateEntryError(Exception):
+    """ Exception """
 class IllegalArgumentException(Exception):
     """ Exception """
 class IllegalStateException(Exception):
@@ -18,6 +20,10 @@ class InternalRpcException(Exception):
     """ Exception """
 class InvalidAndroidPackage(Exception):
     """ Exception """
+class InvalidArgumentError(Exception):
+    """ Exception """
+class InvalidOperationError(Exception):
+    """ Exception """
 class InvalidRootCertificate(Exception):
     """ Exception """
 class MethodNotFoundException(Exception):
@@ -36,9 +42,11 @@ class StaleObjectException(Exception):
     """ Exception """
 class StartupActivityNotFound(Exception):
     """ Exception """
+class StorageOutOfMemory(Exception):
+    """ Exception """
 class UiAutomatorException(Exception):
     """ Exception """
 class UiObjectNotFoundException(Exception):
     """ Exception """
 class UnHandledException(Exception):
-    """ Exception """
+    """ Exception """
\ No newline at end of file
